sf_extSoftVersion: Provide the external dependencies versions of the libraries...

View source: R/init.R

sf_extSoftVersionR Documentation

Provide the external dependencies versions of the libraries linked to sf

Description

Provide the external dependencies versions of the libraries linked to sf

Usage

sf_extSoftVersion()

sf documentation built on Sept. 11, 2026, 9:07 a.m.