Return bounding of a simple feature or simple feature set
NA_bbox_st_bbox(obj)
\method{st_bbox}{POINT}(obj)
\method{st_bbox}{MULTIPOINT}(obj)
\method{st_bbox}{LINESTRING}(obj)
\method{st_bbox}{POLYGON}(obj)
\method{st_bbox}{MULTILINESTRING}(obj)
\method{st_bbox}{MULTIPOLYGON}(obj)
\method{st_bbox}{GEOMETRYCOLLECTION}(obj)
\method{st_bbox}{MULTISURFACE}(obj)
\method{st_bbox}{MULTICURVE}(obj)
\method{st_bbox}{CURVEPOLYGON}(obj)
\method{st_bbox}{COMPOUNDCURVE}(obj)
\method{st_bbox}{POLYHEDRALSURFACE}(obj)
\method{st_bbox}{TIN}(obj)
\method{st_bbox}{TRIANGLE}(obj)
\method{st_bbox}{CIRCULARSTRING}(obj)
\method{st_bbox}{sfc}(obj)
\method{st_bbox}{sf}(obj)
object to compute the bounding box from
a numeric vector of length four, with xmin, ymin, xmax
and ymax values; if obj is of class sf or sfc, the object
returned has a class bbox, an attribute crs and a method to print the
bbox and an st_crs method to retrieve the coordinate reference system
corresponding to obj (and hence the bounding box).
An object of class bbox of length 4.
NA_bbox_ is the bbox object with a missing value.